==> SkyHanni-5.3.0-mc1.21.10-sources.jar: at/hannibal2/skyhanni/features/slayer/SlayerType.kt <==
package at.hannibal2.skyhanni.features.slayer

import net.minecraft.entity.mob.BlazeEntity
import net.minecraft.entity.mob.EndermanEntity
import net.minecraft.entity.mob.SpiderEntity
import net.minecraft.entity.mob.ZombieEntity
import net.minecraft.entity.passive.WolfEntity

enum class SlayerType(
    val displayName: String,
    val rngName: String,
    val clazz: Class<*>,
    val miniBossType: SlayerMiniBossType? = null,
    val otherNames: List<String> = listOf(),
) {
    REVENANT(
        "Revenant Horror",
        "revenant",
        ZombieEntity::class.java,
        SlayerMiniBossType.REVENANT,
        listOf("Atoned Horror"),
    ),
    TARANTULA(
        "Tarantula Broodfather",
        "tarantula",
        SpiderEntity::class.java,
        SlayerMiniBossType.TARANTULA,
        listOf("Conjoined Brood"),
    ),
    SVEN(
        "Sven Packmaster",
        "sven",
        WolfEntity::class.java,
        SlayerMiniBossType.SVEN,
    ),
    VOID(
        "Voidgloom Seraph",
        "voidgloom",
        EndermanEntity::class.java,
        SlayerMiniBossType.VOIDLING,
    ),
    INFERNO(
        "Inferno Demonlord",
        "inferno",
        BlazeEntity::class.java,
        SlayerMiniBossType.INFERNAL,
    ),
    VAMPIRE(
        "Bloodfiend",
        "vampire",
        ZombieEntity::class.java,
    ) // previously called "Riftstalker Bloodfiend"
    ;

    companion object {
        fun getByName(name: String): SlayerType? = entries.firstOrNull { slayer ->
            name.contains(slayer.displayName) || slayer.otherNames.any { name.contains(it) }
        }

        fun getByClassName(name: String): SlayerType? = entries.firstOrNull {
            it.clazz.simpleName.removePrefix("Entity").equals(name, ignoreCase = true)
        }
    }
}

enum class SlayerMiniBossType(vararg names: String) {
    REVENANT("Revenant Sycophant", "Revenant Champion", "Deformed Revenant", "Atoned Champion", "Atoned Revenant"),
    TARANTULA("Tarantula Vermin", "Tarantula Beast", "Mutant Tarantula", "Primordial Jockey", "Primordial Viscount"),
    SVEN("Pack Enforcer", "Sven Follower", "Sven Alpha"),
    VOIDLING("Voidling Devotee", "Voidling Radical", "Voidcrazed Maniac"),
    INFERNAL("Flare Demon", "Kindleheart Demon", "Burningsoul Demon"),
    ;

    val names = names.toSet()

    companion object {
        private val allNames = entries.flatMap { it.names }.toSet()

        fun isMiniboss(name: String) = name in allNames
    }
}

==> SkyHanni-5.4.0-mc1.8.9-sources.jar: at/hannibal2/skyhanni/features/slayer/SlayerType.kt <==
package at.hannibal2.skyhanni.features.slayer

import net.minecraft.entity.monster.EntityBlaze
import net.minecraft.entity.monster.EntityEnderman
import net.minecraft.entity.monster.EntitySpider
import net.minecraft.entity.monster.EntityZombie
import net.minecraft.entity.passive.EntityWolf

enum class SlayerType(
    val displayName: String,
    val rngName: String,
    val clazz: Class<*>,
    val miniBossType: SlayerMiniBossType? = null,
    val otherNames: List<String> = listOf(),
) {
    REVENANT(
        "Revenant Horror",
        "revenant",
        EntityZombie::class.java,
        SlayerMiniBossType.REVENANT,
        listOf("Atoned Horror"),
    ),
    TARANTULA(
        "Tarantula Broodfather",
        "tarantula",
        EntitySpider::class.java,
        SlayerMiniBossType.TARANTULA,
        listOf("Conjoined Brood"),
    ),
    SVEN(
        "Sven Packmaster",
        "sven",
        EntityWolf::class.java,
        SlayerMiniBossType.SVEN,
    ),
    VOID(
        "Voidgloom Seraph",
        "voidgloom",
        EntityEnderman::class.java,
        SlayerMiniBossType.VOIDLING,
    ),
    INFERNO(
        "Inferno Demonlord",
        "inferno",
        EntityBlaze::class.java,
        SlayerMiniBossType.INFERNAL,
    ),
    VAMPIRE(
        "Bloodfiend",
        "vampire",
        EntityZombie::class.java,
    ) // previously called "Riftstalker Bloodfiend"
    ;

    companion object {
        fun getByName(name: String): SlayerType? = entries.firstOrNull { slayer ->
            name.contains(slayer.displayName) || slayer.otherNames.any { name.contains(it) }
        }

        fun getByClassName(name: String): SlayerType? = entries.firstOrNull {
            it.clazz.simpleName.removePrefix("Entity").equals(name, ignoreCase = true)
        }
    }
}

enum class SlayerMiniBossType(vararg names: String) {
    REVENANT("Revenant Sycophant", "Revenant Champion", "Deformed Revenant", "Atoned Champion", "Atoned Revenant"),
    TARANTULA("Tarantula Vermin", "Tarantula Beast", "Mutant Tarantula", "Primordial Jockey", "Primordial Viscount"),
    SVEN("Pack Enforcer", "Sven Follower", "Sven Alpha"),
    VOIDLING("Voidling Devotee", "Voidling Radical", "Voidcrazed Maniac"),
    INFERNAL("Flare Demon", "Kindleheart Demon", "Burningsoul Demon"),
    ;

    val names = names.toSet()

    companion object {
        private val allNames = entries.flatMap { it.names }.toSet()

        fun isMiniboss(name: String) = name in allNames
    }
}
